summaryrefslogtreecommitdiff
path: root/gcc/sched-vis.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/sched-vis.c')
-rw-r--r--gcc/sched-vis.c15
1 files changed, 13 insertions, 2 deletions
diff --git a/gcc/sched-vis.c b/gcc/sched-vis.c
index 2dd20d0cd50..d3e8472b3be 100644
--- a/gcc/sched-vis.c
+++ b/gcc/sched-vis.c
@@ -31,6 +31,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
#include "basic-block.h"
#include "insn-attr.h"
#include "sched-int.h"
+#include "target.h"
#ifdef INSN_SCHEDULING
/* target_units bitmask has 1 for each unit in the cpu. It should be
@@ -38,7 +39,8 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
But currently it is computed by examining the insn list. Since
this is only needed for visualization, it seems an acceptable
solution. (For understanding the mapping of bits to units, see
- definition of function_units[] in "insn-attrtab.c".) */
+ definition of function_units[] in "insn-attrtab.c".) The scheduler
+ using only DFA description should never use the following variable. */
static int target_units = 0;
@@ -122,6 +124,14 @@ get_visual_tbl_length ()
int n, n1;
char *s;
+ if (targetm.sched.use_dfa_pipeline_interface
+ && (*targetm.sched.use_dfa_pipeline_interface) ())
+ {
+ visual_tbl_line_length = 1;
+ return 1; /* Can't return 0 because that will cause problems
+ with alloca. */
+ }
+
/* Compute length of one field in line. */
s = (char *) alloca (INSN_LEN + 6);
sprintf (s, " %33s", "uname");
@@ -815,7 +825,8 @@ print_insn (buf, x, verbose)
}
} /* print_insn */
-/* Print visualization debugging info. */
+/* Print visualization debugging info. The scheduler using only DFA
+ description should never use the following function. */
void
print_block_visualization (s)